dodot-lib 4.1.1

Core library for dodot dotfiles manager
docs.rs failed to build dodot-lib-4.1.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: dodot-lib-4.0.0