discover_and_classify

Function discover_and_classify 

pub fn discover_and_classify(
    ctx: &ExecutionContext,
) -> Result<Vec<TutorialPack>>
Discover packs in the active context and classify each one.

Returns the list in scan order with the recommended starter pack flagged. If no pack is recommendable (only empty packs), no entry has recommended = true.