Module confique_preprocessor_section_layer

Module confique_preprocessor_section_layer 

Generated by confique: helpers to implement Config for PreprocessorSection.

Do not use directly! Only use via the Config and Layer traits and what’s explained in the confique documentation. Any other parts of this module cannot be relied on and are not part of the semver guarantee of confique.

Structs

PreprocessorSectionLayer