pub struct PreprocessorSectionLayer {
pub enabled: Option<bool>,
pub template: <PreprocessorTemplateSection as Config>::Layer,
}Fields
enabled: Option<bool>Global kill switch for all preprocessing.
template: <PreprocessorTemplateSection as Config>::LayerTrait Implementations
Sourceimpl<'de> Deserialize<'de> for PreprocessorSectionLayer
impl<'de> Deserialize<'de> for PreprocessorSectionLayer
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Layer for PreprocessorSectionLayerwhere
PreprocessorTemplateSection: Config,
impl Layer for PreprocessorSectionLayerwhere
PreprocessorTemplateSection: Config,
Sourcefn default_values() -> Self
fn default_values() -> Self
Returns an object containing all default values (i.e. set via
#[config(default = ...)] when deriving Config) with all remaining
values/fields set to None/being empty.Sourcefn from_env() -> Result<Self, Error>
fn from_env() -> Result<Self, Error>
Loads values from environment variables. This is only relevant for
fields annotated with
#[config(env = "...")]: all fields not
annotated env will be None. Read moreSourcefn with_fallback(self, fallback: Self) -> Self
fn with_fallback(self, fallback: Self) -> Self
Combines two layers.
self has a higher priority; missing values in
self are filled with values in fallback, if they exist. The
semantics of this method is basically like in Option::or.Sourcefn is_complete(&self) -> bool
fn is_complete(&self) -> bool
Returns
true if all required (non-optional) values in this
configuration are set. If this returns true, Config::from_layer
will not return an error.Auto Trait Implementations
impl Freeze for PreprocessorSectionLayer
impl RefUnwindSafe for PreprocessorSectionLayer
impl Send for PreprocessorSectionLayer
impl Sync for PreprocessorSectionLayer
impl Unpin for PreprocessorSectionLayer
impl UnsafeUnpin for PreprocessorSectionLayer
impl UnwindSafe for PreprocessorSectionLayer