#[non_exhaustive]pub enum DodotError {
Fs {
path: PathBuf,
source: Error,
},
SymlinkConflict {
path: PathBuf,
},
ProtectedPath {
path: PathBuf,
},
PackNotFound {
name: String,
},
PackInvalid {
name: String,
reason: String,
},
HandlerNotFound {
name: String,
},
Config(String),
CommandFailed {
command: String,
exit_code: i32,
stderr: String,
},
InvalidPattern {
pattern: String,
reason: String,
},
Other(String),
}Expand description
The single error type for all dodot operations.
Each variant carries enough context to produce a useful error message without needing to inspect the source chain.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Fs
SymlinkConflict
ProtectedPath
PackNotFound
PackInvalid
HandlerNotFound
Config(String)
CommandFailed
InvalidPattern
Other(String)