pub struct PathHandler;Trait Implementations
Sourceimpl Handler for PathHandler
impl Handler for PathHandler
Sourcefn category(&self) -> HandlerCategory
fn category(&self) -> HandlerCategory
Whether this is a configuration or code-execution handler.
Sourcefn to_intents(
&self,
matches: &[RuleMatch],
_config: &HandlerConfig,
_paths: &dyn Pather,
_fs: &dyn Fs,
) -> Result<Vec<HandlerIntent>>
fn to_intents( &self, matches: &[RuleMatch], _config: &HandlerConfig, _paths: &dyn Pather, _fs: &dyn Fs, ) -> Result<Vec<HandlerIntent>>
Transform matched files into intents. Read more
Sourcefn check_status(
&self,
file: &Path,
pack: &str,
datastore: &dyn DataStore,
) -> Result<HandlerStatus>
fn check_status( &self, file: &Path, pack: &str, datastore: &dyn DataStore, ) -> Result<HandlerStatus>
Check whether a file has been deployed by this handler.
Sourcefn match_mode(&self) -> MatchMode
fn match_mode(&self) -> MatchMode
How this handler decides what to claim. Read more
Sourcefn scope(&self) -> HandlerScope
fn scope(&self) -> HandlerScope
Whether a match removes the entry from further consideration. Read more