format_deployment_map

Function format_deployment_map 

pub fn format_deployment_map(entries: &[DeploymentMapEntry]) -> String
Format the deployment map as TSV.

The output is deterministic (entries are emitted in the order returned by collect_deployment_map, which sorts by pack, then handler, then entry name).